@@ -267,19 +267,28 @@ int main(int argc, char **orig_argv)
         break;
       case 'O':
         opt->O_option = SPLT_TRUE;
-        mp3splt_set_long_option(state, SPLT_OPT_OVERLAP_TIME,
-            c_hundreths(optarg));
+        long overlap_time = c_hundreths(optarg);
+
+        if (overlap_time != -LONG_MAX)
+        {
+          mp3splt_set_long_option(state, SPLT_OPT_OVERLAP_TIME, overlap_time);
+        }
+        else
+        {
+          print_error_exit(_("bad overlap time expression.\n"
+                "\tMust be min.sec[.0-99] or EOF-min.sec[.0-99], read man page for details."), data);
+        }
         break;
       case 'X':
         opt->X_option = SPLT_TRUE;
         break;
       case 't':
         mp3splt_set_int_option(state, SPLT_OPT_SPLIT_MODE, SPLT_OPTION_TIME_MODE);
-        float converted_time = c_hundreths(optarg);
+        long converted_time = c_hundreths(optarg);
 
         if (converted_time != -LONG_MAX)
         {
-          float split_time = converted_time / 100.0;
+          float split_time = (float)converted_time / 100.0;
           mp3splt_set_float_option(state, SPLT_OPT_SPLIT_TIME, split_time);
         }
         else
@@ -375,12 +384,14 @@ int main(int argc, char **orig_argv)
 
   //add special directory search for plugins on Windows
 #ifdef __WIN32__
-  if (executable != NULL)
+  wchar_t *current_dir = NULL;
+  if (executable_dir != NULL)
   {
-    if (executable[0] != '\0')
+    if (executable_dir[0] != '\0')
     {
-      mp3splt_append_plugins_scan_dir(state, executable);
-      _chdir(executable);
+      mp3splt_append_plugins_scan_dir(state, executable_dir);
+      current_dir = win32_get_current_directory();
+      _chdir(executable_dir);
     }
     free(executable);
     executable = NULL;
@@ -391,12 +402,22 @@ int main(int argc, char **orig_argv)
   err = mp3splt_find_plugins(state);
   process_confirmation_error(err, data);
 
+#ifdef __WIN32__
+  if (current_dir)
+  {
+    win32_set_current_working_directory(current_dir);
+    free(current_dir);
+    current_dir = NULL;
+  }
+#endif
+
   //if we have parameter options
   if (opt->p_option)
   {
-    float th = -200,off = -200,min = -200;
+    float th = -200,off = -200,min = -200, min_track_length = -200;
     int gap = -200,nt = -200,rm = -200;
-    int parsed_p_options = parse_silence_options(opt->param_args, &th, &gap, &nt, &off, &rm, &min);
+    int parsed_p_options = parse_silence_options(opt->param_args, &th, &gap,
+        &nt, &off, &rm, &min, &min_track_length);
     if (parsed_p_options < 1)
     {
       print_error_exit(_("bad argument for -p option. No valid value"
@@ -415,6 +436,10 @@ int main(int argc, char **orig_argv)
     {
       mp3splt_set_float_option(state, SPLT_OPT_PARAM_MIN_LENGTH, min);
     }
+    if (min_track_length != -200)
+    {
+      mp3splt_set_float_option(state, SPLT_OPT_PARAM_MIN_TRACK_LENGTH, min_track_length);
+    }
     if (gap != -200)
     {
       mp3splt_set_int_option(state, SPLT_OPT_PARAM_GAP, gap);
